@@ -1,5 +1,5 @@
 /*
-   @#@#@ $Id: cgnsKeywords.h,v 1.2 2007/12/13 03:19:00 brucewedan Exp $
+   @#@#@ $Id: cgnsKeywords.h,v 1.3 2008/07/11 00:17:37 brucewedan Exp $
    @#@#@ CHECKSUM: 296864779 40788
    @#@#@ (cat cgnsKeywords.h | grep -v '@#@#@' | cksum)
 */
@@ -889,7 +889,7 @@ typedef enum {
 #define RigidGridMotionPointers_s      "RigidGridMotionPointers"
 #define ArbitraryGridMotionPointers_s  "ArbitraryGridMotionPointers"
 #define GridCoordinatesPointers_s      "GridCoordinatesPointers"
-#define FlowSolutionsPointers_s        "FlowSolutionsPointers"
+#define FlowSolutionPointers_s         "FlowSolutionPointers"
 #define OriginLocation_s               "OriginLocation"
 #define RigidRotationAngle_s           "RigidRotationAngle"
 #define RigidVelocity_s                "RigidVelocity"
