@@ -21,8 +21,8 @@ freely, subject to the following restrictions:
 #ifndef CGNSLIB_H
 #define CGNSLIB_H
 
-#define CGNS_VERSION 2530
-#define CGNS_DOTVERS 2.53
+#define CGNS_VERSION 2540
+#define CGNS_DOTVERS 2.54
 
 #ifndef CGNSDLL
 # ifdef _WIN32
@@ -912,7 +912,7 @@ CGNSDLL int cg_diffusion_write(int const * diffusion_model);
  *      EMMagneticFieldModel_t Nodes                                     *
 \* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-CGNSDLL int cg_model_read(char *ModelLabel, ModelType_t *ModelType);
+CGNSDLL int cg_model_read(char const *ModelLabel, ModelType_t *ModelType);
 CGNSDLL int cg_model_write(char const * ModelLabel, ModelType_t ModelType);
 
 /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - *\
